@@ -25,7 +25,7 @@ class SentryManager(models.Manager):
         return qs
 
     def from_kwargs(self, **kwargs):
-        from sentry.models import Message, GroupedMessage
+        from sentry.models import Message, GroupedMessage, FilterValue
         
         URL_MAX_LENGTH = Message._meta.get_field_by_name('url')[0].max_length
         now = datetime.datetime.now()
@@ -75,6 +75,8 @@ class SentryManager(models.Manager):
                 group=group,
                 **kwargs
             )
+            FilterValue.objects.get_or_create(key='server_name', value=server_name)
+            FilterValue.objects.get_or_create(key='logger', value=logger_name)
         except Exception, exc:
             # TODO: should we mail admins when there are failures?
             try:
