@@ -12,6 +12,7 @@ import warnings
 from django.conf import settings as dj_settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models, transaction
+from django.db.models.signals import post_syncdb
 from django.http import Http404
 from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext_lazy as _
@@ -77,8 +78,8 @@ class MessageBase(Model):
     level           = models.PositiveIntegerField(choices=settings.LOG_LEVELS, default=logging.ERROR, blank=True, db_index=True)
     message         = models.TextField()
     traceback       = models.TextField(blank=True, null=True)
-    view            = models.CharField(max_length=255, db_index=True, blank=True, null=True)
-    checksum        = models.CharField(max_length=32, db_index=True)
+    view            = models.CharField(max_length=255, blank=True, null=True)
+    checksum        = models.CharField(max_length=32)
 
     objects         = SentryManager()
 
@@ -107,7 +108,7 @@ class MessageBase(Model):
     description.short_description = _('description')
 
 class GroupedMessage(MessageBase):
-    status          = models.PositiveIntegerField(default=0, choices=STATUS_LEVELS)
+    status          = models.PositiveIntegerField(default=0, choices=STATUS_LEVELS, db_index=True)
     times_seen      = models.PositiveIntegerField(default=1)
     last_seen       = models.DateTimeField(default=datetime.datetime.now, db_index=True)
     first_seen      = models.DateTimeField(default=datetime.datetime.now, db_index=True)
@@ -129,13 +130,28 @@ class GroupedMessage(MessageBase):
     def natural_key(self):
         return (self.logger, self.view, self.checksum)
 
+    @classmethod
+    def create_sort_index(cls, sender, db, created_models, **kwargs):
+        # This is only supported in postgres
+        engine = get_db_engine()
+        if not engine.startswith('postgresql'):
+            return
+        if cls not in created_models:
+            return
+
+        from django.db import connections
+        
+        cursor = connections[db].cursor()
+        cursor.execute("create index sentry_groupedmessage_score on sentry_groupedmessage ((%s))" % (cls.get_score_clause(),))
+        cursor.close()
+
     @classmethod
     def get_score_clause(cls):
         engine = get_db_engine()
         if engine.startswith('postgresql'):
-            return 'times_seen / (pow((floor(extract(epoch from now() - last_seen) / 3600) + 2), 1.25) + 1)'
+            return 'times_seen * 3600 + last_seen::abstime::int'
         if engine.startswith('mysql'):
-            return 'times_seen / (pow((floor((unix_timestamp(now()) - unix_timestamp(last_seen)) / 3600) + 2), 1.25) + 1)'
+            return 'times_seen * 3600 + unix_timestamp(last_seen)'
         return 'times_seen'
 
     def mail_admins(self, request=None, fail_silently=True):
@@ -225,3 +241,19 @@ class Message(MessageBase):
             fake_request.path_info = ''
         fake_request.path = fake_request.path_info
         return fake_request
+
+class FilterValue(models.Model):
+    FILTER_KEYS = (
+        ('server_name', _('server name')),
+        ('logger', _('logger')),
+    )
+    
+    key = models.CharField(choices=FILTER_KEYS, max_length=32)
+    value = models.CharField(max_length=255)
+    
+    class Meta:
+        unique_together = (('key', 'value'),)
+
+# XXX: Django sucks and we can't listen to our specific app
+# post_syncdb.connect(GroupedMessage.create_sort_index, sender=__name__)
+post_syncdb.connect(GroupedMessage.create_sort_index)
\ No newline at end of file
