@@ -641,38 +641,20 @@ class RemoteSentryTest(TestCase):
         self.assertEquals(instance.level, 40)
 
     def testByteSequence(self):
-        """
-        invalid byte sequence for encoding "UTF8": 0xedb7af
-        """
-        fname = os.path.join(os.path.dirname(__file__), 'fixtures/encode_error.json')
-        kwargs = simplejson.load(open(fname))
-        
-        resp = self.client.post(reverse('sentry-store'), {
-            'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
-            'key': settings.KEY,
-        })
-        self.assertEquals(resp.status_code, 200)
-        instance = Message.objects.get()
-        self.assertEquals(instance.message, 'hello')
-        self.assertEquals(instance.server_name, 'localhost')
-        self.assertEquals(instance.level, 40)
-        self.assertTrue(instance.data['__sentry__']['exc'])
-
-    def testUnhandledException(self):
         """
         invalid byte sequence for encoding "UTF8": 0xedb7af
         """
         fname = os.path.join(os.path.dirname(__file__), 'fixtures/bad_data.json')
-        kwargs = simplejson.load(open(fname))
+        data = open(fname).read()
         
         resp = self.client.post(reverse('sentry-store'), {
-            'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
+            'data': data,
             'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
-        self.assertEquals(instance.message, 'hello')
-        self.assertEquals(instance.server_name, 'localhost')
+        self.assertEquals(instance.message, 'invalid byte sequence for encoding "UTF8": 0xeda4ac\nHINT:  This error can also happen if the byte sequence does not match the encoding expected by the server, which is controlled by "client_encoding".\n')
+        self.assertEquals(instance.server_name, 'shilling.disqus.net')
         self.assertEquals(instance.level, 40)
         self.assertTrue(instance.data['__sentry__']['exc'])
 
